@@ -142,7 +142,7 @@ $name_e->pack(-side=>'left');
     $f->pack(-side => 'left', -expand => 'yes', -fill => 'both');
     my $s = $f->Scrollbar(@scalcon);
     $l = $f->Listbox(@liscon,-yscrollcommand => ['set', $s], -setgrid => 1,
-			-width => $maxwidth, -height => $listheight);
+			-width => 20, -height => $listheight);
 
     $s->configure(-command => ['yview', $l]);
     $s->pack(-side => 'right', -fill => 'y');
@@ -165,7 +165,9 @@ $name_e->pack(-side=>'left');
 
 
     my $gf = $hf->Frame(@fracon);
-    $gf -> pack(-side=>'right',-padx=>'4');
+    $gf -> pack(-side=>'right');
+# perl-tk 8 doesn't like padx ?
+#    $gf -> pack(-side=>'right',-padx=>'4');
     my $gbut = $gf->Button(@labcon,-text=>'Gradient');
      $gbut->pack(-side=>'left');
     bind_help($gbut,'File:gradient');
